/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications, Inc.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"

/** 
 * An optional interface for accessing the HTTP or
 * javascript cookie object
 * 
 * @status FROZEN
 */

typedef long nsCookieStatus;
typedef long nsCookiePolicy;

[scriptable, uuid(E9FCB9A4-D376-458f-B720-E65E7DF593BC)]

interface nsICookie : nsISupports {

    /**
     * the name of the cookie
     */
    readonly attribute ACString name;

    /**
     * the cookie value
     */
    readonly attribute ACString value;

    /**
     * true if the cookie is a domain cookie, false otherwise
     */
    readonly attribute boolean isDomain;

    /**
     * the host (possibly fully qualified) of the cookie
     */
    readonly attribute AUTF8String host;

    /**
     * the path pertaining to the cookie
     */
    readonly attribute AUTF8String path;

    /**
     * true if the cookie was transmitted over ssl, false otherwise
     */
    readonly attribute boolean isSecure;

    /**
     * @DEPRECATED use nsICookie2.expiry and nsICookie2.isSession instead.
     *
     * expiration time in seconds since midnight (00:00:00), January 1, 1970 UTC.
     * expires = 0 represents a session cookie.
     * expires = 1 represents an expiration time earlier than Jan 1, 1970.
     */
    readonly attribute PRUint64 expires;

    /**
     * @DEPRECATED status implementation will return STATUS_UNKNOWN in all cases.
     */
    const nsCookieStatus STATUS_UNKNOWN=0;
    const nsCookieStatus STATUS_ACCEPTED=1;
    const nsCookieStatus STATUS_DOWNGRADED=2;
    const nsCookieStatus STATUS_FLAGGED=3;
    const nsCookieStatus STATUS_REJECTED=4;
    readonly attribute nsCookieStatus status;

    /**
     * @DEPRECATED policy implementation will return POLICY_UNKNOWN in all cases.
     */
    const nsCookiePolicy POLICY_UNKNOWN=0;
    const nsCookiePolicy POLICY_NONE=1;
    const nsCookiePolicy POLICY_NO_CONSENT=2;
    const nsCookiePolicy POLICY_IMPLICIT_CONSENT=3;
    const nsCookiePolicy POLICY_EXPLICIT_CONSENT=4;
    const nsCookiePolicy POLICY_NO_II=5;
    readonly attribute nsCookiePolicy policy;

};
